##  Scope
  * SAP LeanIX relies on the API type (MCP) to identify registered MCP servers.
  * The integration supports the global Azure cloud. API calls are routed to the corresponding URL. To learn more about region-specific URIs, consult [Authentication to National Clouds![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fentra%2Fidentity-platform%2Fauthentication-national-cloud "https://learn.microsoft.com/en-us/entra/identity-platform/authentication-national-cloud").
  * Authorization and permissions are managed using the OAuth 2.0 client credentials grant flow. The required scope for API access is https://management.azure.com/.default. For more information, refer to [OAuth 2.0 Client Credentials Grant Flow![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Flearn.microsoft.com%2Fen-us%2Fentra%2Fidentity-platform%2Fv2-oauth2-client-creds-grant-flow%23first-case-access-token-request-with-a-shared-secret "https://learn.microsoft.com/en-us/entra/identity-platform/v2-oauth2-client-creds-grant-flow#first-case-access-token-request-with-a-shared-secret").
